Usage
aftreg.fit(X, Y, dist, strata, offset, init, shape, id, control,
center = NULL)
Arguments
X
The design (covariate) matrix.
Y
A survival object, the response.
dist
Which baseline distribution?
strata
A stratum variable.
init
Initial regression parameter values.
shape
If positive, a fixed value of the shape parameter in the
distribution. Otherwise, the shape is estimated.
id
See corresponding argument to aftreg. control
Controls convergence and output.
center
Is now deprecated. Centering is done internally, but
results reported as if not.